@@ -1,4 +1,4 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-__version__='0.0.1'
\ No newline at end of file
+import sec_to_hms
\ No newline at end of file
